%polarizationModel2 TR 38.901 Section 7.3.2 polarization Model-2
%  A_prime_fn: linear antenna radiation power pattern function 
%              A = A_prime_fn(theta_prime,phi_prime)
% theta_prime: zenith angle in LCS
% phi_prime  : azimuth angle in LCS
% zeta       : polarization slant angle

%   Copyright 2017-2018 The MathWorks, Inc.

%#codegen

function F = polarizationModel2(A_prime_fn,theta_prime,phi_prime,zeta)

    F = kron(sqrt(A_prime_fn(theta_prime,phi_prime)),[cosd(zeta); sind(zeta)]);
    
end
